# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class MoveVirtualNetToDiffSn(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'sn_names': 'list[str]',
        'vc_index': 'int',
        'force': 'bool'
    }

    attribute_map = {
        'sn_names': 'sn_names',
        'vc_index': 'vc_index',
        'force': 'force'
    }

    def __init__(self, sn_names=None, vc_index=None, force=None, _configuration=None):  # noqa: E501
        """MoveVirtualNetToDiffSn - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._sn_names = None
        self._vc_index = None
        self._force = None
        self.discriminator = None

        self.sn_names = sn_names
        self.vc_index = vc_index
        if force is not None:
            self.force = force

    @property
    def sn_names(self):
        """Gets the sn_names of this MoveVirtualNetToDiffSn.  # noqa: E501

        destination storage node(s) for the virtual controller. When selecting multiple destination storage nodes, the VC will be moved to the first storage node with sufficient resources, according to the selected order  # noqa: E501

        :return: The sn_names of this MoveVirtualNetToDiffSn.  # noqa: E501
        :rtype: list[str]
        """
        return self._sn_names

    @sn_names.setter
    def sn_names(self, sn_names):
        """Sets the sn_names of this MoveVirtualNetToDiffSn.

        destination storage node(s) for the virtual controller. When selecting multiple destination storage nodes, the VC will be moved to the first storage node with sufficient resources, according to the selected order  # noqa: E501

        :param sn_names: The sn_names of this MoveVirtualNetToDiffSn.  # noqa: E501
        :type: list[str]
        """
        if self._configuration.client_side_validation and sn_names is None:
            raise ValueError("Invalid value for `sn_names`, must not be `None`")  # noqa: E501

        self._sn_names = sn_names

    @property
    def vc_index(self):
        """Gets the vc_index of this MoveVirtualNetToDiffSn.  # noqa: E501

        Virtual controller index  # noqa: E501

        :return: The vc_index of this MoveVirtualNetToDiffSn.  # noqa: E501
        :rtype: int
        """
        return self._vc_index

    @vc_index.setter
    def vc_index(self, vc_index):
        """Sets the vc_index of this MoveVirtualNetToDiffSn.

        Virtual controller index  # noqa: E501

        :param vc_index: The vc_index of this MoveVirtualNetToDiffSn.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and vc_index is None:
            raise ValueError("Invalid value for `vc_index`, must not be `None`")  # noqa: E501

        self._vc_index = vc_index

    @property
    def force(self):
        """Gets the force of this MoveVirtualNetToDiffSn.  # noqa: E501

        In case the Storage Node that hosts the VC is offline and marked for decommission, use the force flag to allow the VC relocation.  # noqa: E501

        :return: The force of this MoveVirtualNetToDiffSn.  # noqa: E501
        :rtype: bool
        """
        return self._force

    @force.setter
    def force(self, force):
        """Sets the force of this MoveVirtualNetToDiffSn.

        In case the Storage Node that hosts the VC is offline and marked for decommission, use the force flag to allow the VC relocation.  # noqa: E501

        :param force: The force of this MoveVirtualNetToDiffSn.  # noqa: E501
        :type: bool
        """

        self._force = force

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MoveVirtualNetToDiffSn, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MoveVirtualNetToDiffSn):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MoveVirtualNetToDiffSn):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    Zadara VPSA Object Storage REST API

    # Overview  This document outlines the methods available for administrating your VPSA&#174; Object Storage. The API supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or through the X-Access-Key header. Alternately, you can use the username and password parameters for authentication, but we do not recommend this method for anything other than possibly retrieving an API key.  By default , all operations are allowed only to VPSA Object Storage admin. Some actions are allowed by an account admin and they will be marked on the action's header  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some time to complete. When using the API, this can cause some actions, such as adding drives to storage policy, to be undesirably asynchronous. You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Metering API  Metering information can be retrieved using the VPSA Object Storage API for the following components:  - Accounts - Users - Drives - Virtual Controllers - Load Balancer Groups - Storage Policies  Metering information returned by the API is subject to the following constraints:  - 10 seconds interval - 1 hour range - 1 minute interval - 1 day range - 1 hour interval - 30 days range  Values outside the accepted range will be returned as 0.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import apis into sdk package
from Zios.api.accounts_api import AccountsApi
from Zios.api.drives_api import DrivesApi
from Zios.api.load_balancer_api import LoadBalancerApi
from Zios.api.logs_api import LogsApi
from Zios.api.object_storage_destinations_api import ObjectStorageDestinationsApi
from Zios.api.roles_api import RolesApi
from Zios.api.settings_api import SettingsApi
from Zios.api.storage_policies_api import StoragePoliciesApi
from Zios.api.usage_reports_api import UsageReportsApi
from Zios.api.users_api import UsersApi
from Zios.api.virtual_controllers_api import VirtualControllersApi

# import ApiClient
from Zios.api_client import ApiClient
from Zios.configuration import Configuration
# import models into sdk package
from Zios.models.add_new_user import AddNewUser
from Zios.models.allow_tenant_name_in_object_stroage_url import AllowTenantNameInObjectStroageUrl
from Zios.models.change_mtu_for_network_interface import ChangeMtuForNetworkInterface
from Zios.models.change_password import ChangePassword
from Zios.models.change_region import ChangeRegion
from Zios.models.change_user_pass_by_code import ChangeUserPassByCode
from Zios.models.change_user_role import ChangeUserRole
from Zios.models.create_account import CreateAccount
from Zios.models.create_account_requests import CreateAccountRequests
from Zios.models.create_object_storage_destination import CreateObjectStorageDestination
from Zios.models.default import Default
from Zios.models.default_response import DefaultResponse
from Zios.models.define_custom_dns_servers import DefineCustomDnsServers
from Zios.models.delete_account import DeleteAccount
from Zios.models.delete_drives_from_policy import DeleteDrivesFromPolicy
from Zios.models.delete_object_storage_destination import DeleteObjectStorageDestination
from Zios.models.delete_proxy_virtual_controller import DeleteProxyVirtualController
from Zios.models.error import Error
from Zios.models.get_auth_token import GetAuthToken
from Zios.models.inline_response200 import InlineResponse200
from Zios.models.inline_response2001 import InlineResponse2001
from Zios.models.inline_response20010 import InlineResponse20010
from Zios.models.inline_response20010_response import InlineResponse20010Response
from Zios.models.inline_response20011 import InlineResponse20011
from Zios.models.inline_response20011_response import InlineResponse20011Response
from Zios.models.inline_response20012 import InlineResponse20012
from Zios.models.inline_response20012_objects import InlineResponse20012Objects
from Zios.models.inline_response20013 import InlineResponse20013
from Zios.models.inline_response20013_objects import InlineResponse20013Objects
from Zios.models.inline_response20014 import InlineResponse20014
from Zios.models.inline_response20014_objects import InlineResponse20014Objects
from Zios.models.inline_response20015 import InlineResponse20015
from Zios.models.inline_response20015_response import InlineResponse20015Response
from Zios.models.inline_response20015_response_disks import InlineResponse20015ResponseDisks
from Zios.models.inline_response20016 import InlineResponse20016
from Zios.models.inline_response20016_response import InlineResponse20016Response
from Zios.models.inline_response20016_response_disk import InlineResponse20016ResponseDisk
from Zios.models.inline_response20017 import InlineResponse20017
from Zios.models.inline_response20017_response import InlineResponse20017Response
from Zios.models.inline_response20017_response_lbgs import InlineResponse20017ResponseLbgs
from Zios.models.inline_response20018 import InlineResponse20018
from Zios.models.inline_response20018_response import InlineResponse20018Response
from Zios.models.inline_response20018_response_lbg import InlineResponse20018ResponseLbg
from Zios.models.inline_response20019 import InlineResponse20019
from Zios.models.inline_response20019_response import InlineResponse20019Response
from Zios.models.inline_response20019_response_messages import InlineResponse20019ResponseMessages
from Zios.models.inline_response2001_response import InlineResponse2001Response
from Zios.models.inline_response2002 import InlineResponse2002
from Zios.models.inline_response20020 import InlineResponse20020
from Zios.models.inline_response20020_response import InlineResponse20020Response
from Zios.models.inline_response20020_response_access_logs import InlineResponse20020ResponseAccessLogs
from Zios.models.inline_response20021 import InlineResponse20021
from Zios.models.inline_response20021_response import InlineResponse20021Response
from Zios.models.inline_response20021_response_container_replication_targets import InlineResponse20021ResponseContainerReplicationTargets
from Zios.models.inline_response20022 import InlineResponse20022
from Zios.models.inline_response20022_response import InlineResponse20022Response
from Zios.models.inline_response20023 import InlineResponse20023
from Zios.models.inline_response20023_response import InlineResponse20023Response
from Zios.models.inline_response20023_response_target import InlineResponse20023ResponseTarget
from Zios.models.inline_response20024 import InlineResponse20024
from Zios.models.inline_response20024_response import InlineResponse20024Response
from Zios.models.inline_response20025 import InlineResponse20025
from Zios.models.inline_response20025_response import InlineResponse20025Response
from Zios.models.inline_response20026 import InlineResponse20026
from Zios.models.inline_response20026_response import InlineResponse20026Response
from Zios.models.inline_response20026_response_roles import InlineResponse20026ResponseRoles
from Zios.models.inline_response20027 import InlineResponse20027
from Zios.models.inline_response20027_response import InlineResponse20027Response
from Zios.models.inline_response20028 import InlineResponse20028
from Zios.models.inline_response20028_response import InlineResponse20028Response
from Zios.models.inline_response20029 import InlineResponse20029
from Zios.models.inline_response20029_response import InlineResponse20029Response
from Zios.models.inline_response2002_response import InlineResponse2002Response
from Zios.models.inline_response2002_response_account import InlineResponse2002ResponseAccount
from Zios.models.inline_response2003 import InlineResponse2003
from Zios.models.inline_response20030 import InlineResponse20030
from Zios.models.inline_response20030_response import InlineResponse20030Response
from Zios.models.inline_response20031 import InlineResponse20031
from Zios.models.inline_response20031_response import InlineResponse20031Response
from Zios.models.inline_response20032 import InlineResponse20032
from Zios.models.inline_response20032_response import InlineResponse20032Response
from Zios.models.inline_response20033 import InlineResponse20033
from Zios.models.inline_response20033_response import InlineResponse20033Response
from Zios.models.inline_response20034 import InlineResponse20034
from Zios.models.inline_response20034_response import InlineResponse20034Response
from Zios.models.inline_response20034_response_policies import InlineResponse20034ResponsePolicies
from Zios.models.inline_response20035 import InlineResponse20035
from Zios.models.inline_response20035_response import InlineResponse20035Response
from Zios.models.inline_response20035_response_policy import InlineResponse20035ResponsePolicy
from Zios.models.inline_response20036 import InlineResponse20036
from Zios.models.inline_response20036_response import InlineResponse20036Response
from Zios.models.inline_response20037 import InlineResponse20037
from Zios.models.inline_response20037_response import InlineResponse20037Response
from Zios.models.inline_response20038 import InlineResponse20038
from Zios.models.inline_response20038_response import InlineResponse20038Response
from Zios.models.inline_response20039 import InlineResponse20039
from Zios.models.inline_response20039_objects import InlineResponse20039Objects
from Zios.models.inline_response2003_response import InlineResponse2003Response
from Zios.models.inline_response2004 import InlineResponse2004
from Zios.models.inline_response20040 import InlineResponse20040
from Zios.models.inline_response20040_response import InlineResponse20040Response
from Zios.models.inline_response20040_response_usage import InlineResponse20040ResponseUsage
from Zios.models.inline_response20040_response_usage_account_usage_summary import InlineResponse20040ResponseUsageAccountUsageSummary
from Zios.models.inline_response20040_response_usage_report_header import InlineResponse20040ResponseUsageReportHeader
from Zios.models.inline_response20040_response_usage_report_header_policy_capacity_usage_cost_gbmonth import InlineResponse20040ResponseUsageReportHeaderPolicyCapacityUsageCostGbmonth
from Zios.models.inline_response20040_response_usage_report_header_reporting_interval import InlineResponse20040ResponseUsageReportHeaderReportingInterval
from Zios.models.inline_response20040_response_usage_usage_summary import InlineResponse20040ResponseUsageUsageSummary
from Zios.models.inline_response20041 import InlineResponse20041
from Zios.models.inline_response20041_response import InlineResponse20041Response
from Zios.models.inline_response20041_response_roles import InlineResponse20041ResponseRoles
from Zios.models.inline_response20041_response_users import InlineResponse20041ResponseUsers
from Zios.models.inline_response20041_response_zios_data import InlineResponse20041ResponseZiosData
from Zios.models.inline_response20041_response_zios_data_zios_user import InlineResponse20041ResponseZiosDataZiosUser
from Zios.models.inline_response20041_response_zios_data_zios_user_roles import InlineResponse20041ResponseZiosDataZiosUserRoles
from Zios.models.inline_response20042 import InlineResponse20042
from Zios.models.inline_response20042_response import InlineResponse20042Response
from Zios.models.inline_response20043 import InlineResponse20043
from Zios.models.inline_response20043_response import InlineResponse20043Response
from Zios.models.inline_response20043_response_user import InlineResponse20043ResponseUser
from Zios.models.inline_response20044 import InlineResponse20044
from Zios.models.inline_response20044_response import InlineResponse20044Response
from Zios.models.inline_response20044_response_user import InlineResponse20044ResponseUser
from Zios.models.inline_response20044_response_user_zios_data import InlineResponse20044ResponseUserZiosData
from Zios.models.inline_response20044_response_user_zios_data_zios_user import InlineResponse20044ResponseUserZiosDataZiosUser
from Zios.models.inline_response20045 import InlineResponse20045
from Zios.models.inline_response20045_response import InlineResponse20045Response
from Zios.models.inline_response20046 import InlineResponse20046
from Zios.models.inline_response20046_response import InlineResponse20046Response
from Zios.models.inline_response20047 import InlineResponse20047
from Zios.models.inline_response20047_response import InlineResponse20047Response
from Zios.models.inline_response20048 import InlineResponse20048
from Zios.models.inline_response20048_response import InlineResponse20048Response
from Zios.models.inline_response20048_response_credentials import InlineResponse20048ResponseCredentials
from Zios.models.inline_response20049 import InlineResponse20049
from Zios.models.inline_response20049_response import InlineResponse20049Response
from Zios.models.inline_response20049_response_user import InlineResponse20049ResponseUser
from Zios.models.inline_response20049_response_user_roles import InlineResponse20049ResponseUserRoles
from Zios.models.inline_response20049_response_user_zios_data import InlineResponse20049ResponseUserZiosData
from Zios.models.inline_response20049_response_user_zios_data_zios_user import InlineResponse20049ResponseUserZiosDataZiosUser
from Zios.models.inline_response20049_response_user_zios_data_zios_user_roles import InlineResponse20049ResponseUserZiosDataZiosUserRoles
from Zios.models.inline_response2004_response import InlineResponse2004Response
from Zios.models.inline_response2004_response_users import InlineResponse2004ResponseUsers
from Zios.models.inline_response2005 import InlineResponse2005
from Zios.models.inline_response20050 import InlineResponse20050
from Zios.models.inline_response20051 import InlineResponse20051
from Zios.models.inline_response20052 import InlineResponse20052
from Zios.models.inline_response20052_response import InlineResponse20052Response
from Zios.models.inline_response20052_response_vcs import InlineResponse20052ResponseVcs
from Zios.models.inline_response20053 import InlineResponse20053
from Zios.models.inline_response20053_response import InlineResponse20053Response
from Zios.models.inline_response20053_response_vc import InlineResponse20053ResponseVc
from Zios.models.inline_response20054 import InlineResponse20054
from Zios.models.inline_response20054_response import InlineResponse20054Response
from Zios.models.inline_response20054_response_disks import InlineResponse20054ResponseDisks
from Zios.models.inline_response20055 import InlineResponse20055
from Zios.models.inline_response20055_response import InlineResponse20055Response
from Zios.models.inline_response20056 import InlineResponse20056
from Zios.models.inline_response20056_objects import InlineResponse20056Objects
from Zios.models.inline_response2005_response import InlineResponse2005Response
from Zios.models.inline_response2006 import InlineResponse2006
from Zios.models.inline_response2006_response import InlineResponse2006Response
from Zios.models.inline_response2007 import InlineResponse2007
from Zios.models.inline_response2007_response import InlineResponse2007Response
from Zios.models.inline_response2008 import InlineResponse2008
from Zios.models.inline_response2008_response import InlineResponse2008Response
from Zios.models.inline_response2008_response_arguments import InlineResponse2008ResponseArguments
from Zios.models.inline_response2008_response_requests import InlineResponse2008ResponseRequests
from Zios.models.inline_response2009 import InlineResponse2009
from Zios.models.inline_response2009_response import InlineResponse2009Response
from Zios.models.inline_response200_response import InlineResponse200Response
from Zios.models.inline_response200_response_accounts import InlineResponse200ResponseAccounts
from Zios.models.issue_temp_code_to_mail import IssueTempCodeToMail
from Zios.models.reset_token import ResetToken
from Zios.models.reset_user_s3_keys import ResetUserS3Keys
from Zios.models.restore_encryption import RestoreEncryption
from Zios.models.set_api_errors_alerts import SetApiErrorsAlerts
from Zios.models.set_api_hostname import SetApiHostname
from Zios.models.set_api_ip import SetApiIp
from Zios.models.set_billing_currency import SetBillingCurrency
from Zios.models.set_containers_virtual_hosted_style_support import SetContainersVirtualHostedStyleSupport
from Zios.models.set_data_transfer_pricing import SetDataTransferPricing
from Zios.models.set_encryption import SetEncryption
from Zios.models.set_global_rate_limit import SetGlobalRateLimit
from Zios.models.set_gradual_policy_expansion_percentage import SetGradualPolicyExpansionPercentage
from Zios.models.set_lb_mode import SetLbMode
from Zios.models.set_public_ip_hostname import SetPublicIpHostname
from Zios.models.ssl_termination import SslTermination
from Zios.models.token_expiration import TokenExpiration
from Zios.models.update_object_storage_destination import UpdateObjectStorageDestination
from Zios.models.update_storage_policy import UpdateStoragePolicy
from Zios.models.upload_ssl_pem import UploadSslPem



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class InlineResponse20068ResponsePool(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'display_name': 'str',
        'status': 'str',
        'capacity': 'int',
        'available_capacity': 'float',
        'version': 'int',
        'data_type': 'str',
        'mount_sync': 'str',
        'access_time_update': 'str',
        'raid_group_name': 'str',
        'mode': 'str',
        'stripe_size': 'int',
        'cache': 'str',
        'cow_cache': 'str',
        'capacity_mode': 'str',
        'capacity_history': 'int',
        'alert_mode': 'int',
        'protected_mode': 'int',
        'emergency_mode': 'int',
        'chunk_size': 'int',
        'type': 'str',
        'created_at': 'str',
        'modified_at': 'str',
        'metadata_capacity': 'float',
        'av_protected_capacity': 'float',
        'provisioned_capacity': 'float',
        'ssd': 'InlineResponse20068ResponsePoolSsd',
        'hdd': 'InlineResponse20068ResponsePoolSsd',
        'obs': 'InlineResponse20068ResponsePoolSsd',
        'antivirus': 'str',
        'maintenance_mode': 'str',
        'cool_off_hours': 'int',
        'thresholds': 'str',
        'comment': 'str'
    }

    attribute_map = {
        'name': 'name',
        'display_name': 'display_name',
        'status': 'status',
        'capacity': 'capacity',
        'available_capacity': 'available_capacity',
        'version': 'version',
        'data_type': 'data_type',
        'mount_sync': 'mount_sync',
        'access_time_update': 'access_time_update',
        'raid_group_name': 'raid_group_name',
        'mode': 'mode',
        'stripe_size': 'stripe_size',
        'cache': 'cache',
        'cow_cache': 'cow_cache',
        'capacity_mode': 'capacity_mode',
        'capacity_history': 'capacity_history',
        'alert_mode': 'alert_mode',
        'protected_mode': 'protected_mode',
        'emergency_mode': 'emergency_mode',
        'chunk_size': 'chunk_size',
        'type': 'type',
        'created_at': 'created_at',
        'modified_at': 'modified_at',
        'metadata_capacity': 'metadata_capacity',
        'av_protected_capacity': 'av_protected_capacity',
        'provisioned_capacity': 'provisioned_capacity',
        'ssd': 'ssd',
        'hdd': 'hdd',
        'obs': 'obs',
        'antivirus': 'antivirus',
        'maintenance_mode': 'maintenance_mode',
        'cool_off_hours': 'cool_off_hours',
        'thresholds': 'thresholds',
        'comment': 'comment'
    }

    def __init__(self, name=None, display_name=None, status=None, capacity=None, available_capacity=None, version=None, data_type=None, mount_sync=None, access_time_update=None, raid_group_name=None, mode=None, stripe_size=None, cache=None, cow_cache=None, capacity_mode=None, capacity_history=None, alert_mode=None, protected_mode=None, emergency_mode=None, chunk_size=None, type=None, created_at=None, modified_at=None, metadata_capacity=None, av_protected_capacity=None, provisioned_capacity=None, ssd=None, hdd=None, obs=None, antivirus=None, maintenance_mode=None, cool_off_hours=None, thresholds=None, comment=None, _configuration=None):  # noqa: E501
        """InlineResponse20068ResponsePool - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._display_name = None
        self._status = None
        self._capacity = None
        self._available_capacity = None
        self._version = None
        self._data_type = None
        self._mount_sync = None
        self._access_time_update = None
        self._raid_group_name = None
        self._mode = None
        self._stripe_size = None
        self._cache = None
        self._cow_cache = None
        self._capacity_mode = None
        self._capacity_history = None
        self._alert_mode = None
        self._protected_mode = None
        self._emergency_mode = None
        self._chunk_size = None
        self._type = None
        self._created_at = None
        self._modified_at = None
        self._metadata_capacity = None
        self._av_protected_capacity = None
        self._provisioned_capacity = None
        self._ssd = None
        self._hdd = None
        self._obs = None
        self._antivirus = None
        self._maintenance_mode = None
        self._cool_off_hours = None
        self._thresholds = None
        self._comment = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if display_name is not None:
            self.display_name = display_name
        if status is not None:
            self.status = status
        if capacity is not None:
            self.capacity = capacity
        if available_capacity is not None:
            self.available_capacity = available_capacity
        if version is not None:
            self.version = version
        if data_type is not None:
            self.data_type = data_type
        if mount_sync is not None:
            self.mount_sync = mount_sync
        if access_time_update is not None:
            self.access_time_update = access_time_update
        if raid_group_name is not None:
            self.raid_group_name = raid_group_name
        if mode is not None:
            self.mode = mode
        if stripe_size is not None:
            self.stripe_size = stripe_size
        if cache is not None:
            self.cache = cache
        if cow_cache is not None:
            self.cow_cache = cow_cache
        if capacity_mode is not None:
            self.capacity_mode = capacity_mode
        if capacity_history is not None:
            self.capacity_history = capacity_history
        if alert_mode is not None:
            self.alert_mode = alert_mode
        if protected_mode is not None:
            self.protected_mode = protected_mode
        if emergency_mode is not None:
            self.emergency_mode = emergency_mode
        if chunk_size is not None:
            self.chunk_size = chunk_size
        if type is not None:
            self.type = type
        if created_at is not None:
            self.created_at = created_at
        if modified_at is not None:
            self.modified_at = modified_at
        if metadata_capacity is not None:
            self.metadata_capacity = metadata_capacity
        if av_protected_capacity is not None:
            self.av_protected_capacity = av_protected_capacity
        if provisioned_capacity is not None:
            self.provisioned_capacity = provisioned_capacity
        if ssd is not None:
            self.ssd = ssd
        if hdd is not None:
            self.hdd = hdd
        if obs is not None:
            self.obs = obs
        if antivirus is not None:
            self.antivirus = antivirus
        if maintenance_mode is not None:
            self.maintenance_mode = maintenance_mode
        if cool_off_hours is not None:
            self.cool_off_hours = cool_off_hours
        if thresholds is not None:
            self.thresholds = thresholds
        if comment is not None:
            self.comment = comment

    @property
    def name(self):
        """Gets the name of this InlineResponse20068ResponsePool.  # noqa: E501


        :return: The name of this InlineResponse20068ResponsePool.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse20068ResponsePool.


        :param name: The name of this InlineResponse20068ResponsePool.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def display_name(self):
        """Gets the display_name of this InlineResponse20068ResponsePool.  # noqa: E501


        :return: The display_name of this InlineResponse20068ResponsePool.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this InlineResponse20068ResponsePool.


        :param display_name: The display_name of this InlineResponse20068ResponsePool.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def status(self):
        """Gets the status of this InlineResponse20068ResponsePool.  # noqa: E501


        :return: The status of this InlineResponse20068ResponsePool.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this InlineResponse20068ResponsePool.


        :param status: The status of this InlineResponse20068ResponsePool.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def capacity(self):
        """Gets the capacity of this InlineResponse20068ResponsePool.  # noqa: E501


        :return: The capacity of this InlineResponse20068ResponsePool.  # noqa: E501
        :rtype: int
        """
        return self._capacity

    @capacity.setter
    def capacity(self, capacity):
        """Sets the capacity of this InlineResponse20068ResponsePool.


        :param capacity: The capacity of this InlineResponse20068ResponsePool.  # noqa: E501
        :type: int
        """
        if (self._configuration.client_side_validation and
                capacity is not None and capacity < 1):  # noqa: E501
            raise ValueError("Invalid value for `capacity`, must be a value greater than or equal to `1`")  # noqa: E501

        self._capacity = capacity

    @property
    def available_capacity(self):
        """Gets the available_capacity of this InlineResponse20068ResponsePool.  # noqa: E501


        :return: The available_capacity of this InlineResponse20068ResponsePool.  # noqa: E501
        :rtype: float
        """
        return self._available_capacity

    @available_capacity.setter
    def available_capacity(self, available_capacity):
        """Sets the available_capacity of this InlineResponse20068ResponsePool.


        :param available_capacity: The available_capacity of this InlineResponse20068ResponsePool.  # noqa: E501
        :type: float
        """

        self._available_capacity = available_capacity

    @property
    def version(self):
        """Gets the version of this InlineResponse20068ResponsePool.  # noqa: E501


        :return: The version of this InlineResponse20068ResponsePool.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this InlineResponse20068ResponsePool.


        :param version: The version of this InlineResponse20068ResponsePool.  # noqa: E501
        :type: int
        """

        self._version = version

    @property
    def data_type(self):
        """Gets the data_type of this InlineResponse20068ResponsePool.  # noqa: E501


        :return: The data_type of this InlineResponse20068ResponsePool.  # noqa: E501
        :rtype: str
        """
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        """Sets the data_type of this InlineResponse20068ResponsePool.


        :param data_type: The data_type of this InlineResponse20068ResponsePool.  # noqa: E501
        :type: str
        """

        self._data_type = data_type

    @property
    def mount_sync(self):
        """Gets the mount_sync of this InlineResponse20068ResponsePool.  # noqa: E501


        :return: The mount_sync of this InlineResponse20068ResponsePool.  # noqa: E501
        :rtype: str
        """
        return self._mount_sync

    @mount_sync.setter
    def mount_sync(self, mount_sync):
        """Sets the mount_sync of this InlineResponse20068ResponsePool.


        :param mount_sync: The mount_sync of this InlineResponse20068ResponsePool.  # noqa: E501
        :type: str
        """

        self._mount_sync = mount_sync

    @property
    def access_time_update(self):
        """Gets the access_time_update of this InlineResponse20068ResponsePool.  # noqa: E501


        :return: The access_time_update of this InlineResponse20068ResponsePool.  # noqa: E501
        :rtype: str
        """
        return self._access_time_update

    @access_time_update.setter
    def access_time_update(self, access_time_update):
        """Sets the access_time_update of this InlineResponse20068ResponsePool.


        :param access_time_update: The access_time_update of this InlineResponse20068ResponsePool.  # noqa: E501
        :type: str
        """

        self._access_time_update = access_time_update

    @property
    def raid_group_name(self):
        """Gets the raid_group_name of this InlineResponse20068ResponsePool.  # noqa: E501


        :return: The raid_group_name of this InlineResponse20068ResponsePool.  # noqa: E501
        :rtype: str
        """
        return self._raid_group_name

    @raid_group_name.setter
    def raid_group_name(self, raid_group_name):
        """Sets the raid_group_name of this InlineResponse20068ResponsePool.


        :param raid_group_name: The raid_group_name of this InlineResponse20068ResponsePool.  # noqa: E501
        :type: str
        """

        self._raid_group_name = raid_group_name

    @property
    def mode(self):
        """Gets the mode of this InlineResponse20068ResponsePool.  # noqa: E501


        :return: The mode of this InlineResponse20068ResponsePool.  # noqa: E501
        :rtype: str
        """
        return self._mode

    @mode.setter
    def mode(self, mode):
        """Sets the mode of this InlineResponse20068ResponsePool.


        :param mode: The mode of this InlineResponse20068ResponsePool.  # noqa: E501
        :type: str
        """

        self._mode = mode

    @property
    def stripe_size(self):
        """Gets the stripe_size of this InlineResponse20068ResponsePool.  # noqa: E501


        :return: The stripe_size of this InlineResponse20068ResponsePool.  # noqa: E501
        :rtype: int
        """
        return self._stripe_size

    @stripe_size.setter
    def stripe_size(self, stripe_size):
        """Sets the stripe_size of this InlineResponse20068ResponsePool.


        :param stripe_size: The stripe_size of this InlineResponse20068ResponsePool.  # noqa: E501
        :type: int
        """

        self._stripe_size = stripe_size

    @property
    def cache(self):
        """Gets the cache of this InlineResponse20068ResponsePool.  # noqa: E501


        :return: The cache of this InlineResponse20068ResponsePool.  # noqa: E501
        :rtype: str
        """
        return self._cache

    @cache.setter
    def cache(self, cache):
        """Sets the cache of this InlineResponse20068ResponsePool.


        :param cache: The cache of this InlineResponse20068ResponsePool.  # noqa: E501
        :type: str
        """

        self._cache = cache

    @property
    def cow_cache(self):
        """Gets the cow_cache of this InlineResponse20068ResponsePool.  # noqa: E501


        :return: The cow_cache of this InlineResponse20068ResponsePool.  # noqa: E501
        :rtype: str
        """
        return self._cow_cache

    @cow_cache.setter
    def cow_cache(self, cow_cache):
        """Sets the cow_cache of this InlineResponse20068ResponsePool.


        :param cow_cache: The cow_cache of this InlineResponse20068ResponsePool.  # noqa: E501
        :type: str
        """

        self._cow_cache = cow_cache

    @property
    def capacity_mode(self):
        """Gets the capacity_mode of this InlineResponse20068ResponsePool.  # noqa: E501


        :return: The capacity_mode of this InlineResponse20068ResponsePool.  # noqa: E501
        :rtype: str
        """
        return self._capacity_mode

    @capacity_mode.setter
    def capacity_mode(self, capacity_mode):
        """Sets the capacity_mode of this InlineResponse20068ResponsePool.


        :param capacity_mode: The capacity_mode of this InlineResponse20068ResponsePool.  # noqa: E501
        :type: str
        """

        self._capacity_mode = capacity_mode

    @property
    def capacity_history(self):
        """Gets the capacity_history of this InlineResponse20068ResponsePool.  # noqa: E501


        :return: The capacity_history of this InlineResponse20068ResponsePool.  # noqa: E501
        :rtype: int
        """
        return self._capacity_history

    @capacity_history.setter
    def capacity_history(self, capacity_history):
        """Sets the capacity_history of this InlineResponse20068ResponsePool.


        :param capacity_history: The capacity_history of this InlineResponse20068ResponsePool.  # noqa: E501
        :type: int
        """

        self._capacity_history = capacity_history

    @property
    def alert_mode(self):
        """Gets the alert_mode of this InlineResponse20068ResponsePool.  # noqa: E501


        :return: The alert_mode of this InlineResponse20068ResponsePool.  # noqa: E501
        :rtype: int
        """
        return self._alert_mode

    @alert_mode.setter
    def alert_mode(self, alert_mode):
        """Sets the alert_mode of this InlineResponse20068ResponsePool.


        :param alert_mode: The alert_mode of this InlineResponse20068ResponsePool.  # noqa: E501
        :type: int
        """

        self._alert_mode = alert_mode

    @property
    def protected_mode(self):
        """Gets the protected_mode of this InlineResponse20068ResponsePool.  # noqa: E501


        :return: The protected_mode of this InlineResponse20068ResponsePool.  # noqa: E501
        :rtype: int
        """
        return self._protected_mode

    @protected_mode.setter
    def protected_mode(self, protected_mode):
        """Sets the protected_mode of this InlineResponse20068ResponsePool.


        :param protected_mode: The protected_mode of this InlineResponse20068ResponsePool.  # noqa: E501
        :type: int
        """

        self._protected_mode = protected_mode

    @property
    def emergency_mode(self):
        """Gets the emergency_mode of this InlineResponse20068ResponsePool.  # noqa: E501


        :return: The emergency_mode of this InlineResponse20068ResponsePool.  # noqa: E501
        :rtype: int
        """
        return self._emergency_mode

    @emergency_mode.setter
    def emergency_mode(self, emergency_mode):
        """Sets the emergency_mode of this InlineResponse20068ResponsePool.


        :param emergency_mode: The emergency_mode of this InlineResponse20068ResponsePool.  # noqa: E501
        :type: int
        """

        self._emergency_mode = emergency_mode

    @property
    def chunk_size(self):
        """Gets the chunk_size of this InlineResponse20068ResponsePool.  # noqa: E501


        :return: The chunk_size of this InlineResponse20068ResponsePool.  # noqa: E501
        :rtype: int
        """
        return self._chunk_size

    @chunk_size.setter
    def chunk_size(self, chunk_size):
        """Sets the chunk_size of this InlineResponse20068ResponsePool.


        :param chunk_size: The chunk_size of this InlineResponse20068ResponsePool.  # noqa: E501
        :type: int
        """

        self._chunk_size = chunk_size

    @property
    def type(self):
        """Gets the type of this InlineResponse20068ResponsePool.  # noqa: E501


        :return: The type of this InlineResponse20068ResponsePool.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this InlineResponse20068ResponsePool.


        :param type: The type of this InlineResponse20068ResponsePool.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def created_at(self):
        """Gets the created_at of this InlineResponse20068ResponsePool.  # noqa: E501


        :return: The created_at of this InlineResponse20068ResponsePool.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this InlineResponse20068ResponsePool.


        :param created_at: The created_at of this InlineResponse20068ResponsePool.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def modified_at(self):
        """Gets the modified_at of this InlineResponse20068ResponsePool.  # noqa: E501


        :return: The modified_at of this InlineResponse20068ResponsePool.  # noqa: E501
        :rtype: str
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this InlineResponse20068ResponsePool.


        :param modified_at: The modified_at of this InlineResponse20068ResponsePool.  # noqa: E501
        :type: str
        """

        self._modified_at = modified_at

    @property
    def metadata_capacity(self):
        """Gets the metadata_capacity of this InlineResponse20068ResponsePool.  # noqa: E501


        :return: The metadata_capacity of this InlineResponse20068ResponsePool.  # noqa: E501
        :rtype: float
        """
        return self._metadata_capacity

    @metadata_capacity.setter
    def metadata_capacity(self, metadata_capacity):
        """Sets the metadata_capacity of this InlineResponse20068ResponsePool.


        :param metadata_capacity: The metadata_capacity of this InlineResponse20068ResponsePool.  # noqa: E501
        :type: float
        """

        self._metadata_capacity = metadata_capacity

    @property
    def av_protected_capacity(self):
        """Gets the av_protected_capacity of this InlineResponse20068ResponsePool.  # noqa: E501


        :return: The av_protected_capacity of this InlineResponse20068ResponsePool.  # noqa: E501
        :rtype: float
        """
        return self._av_protected_capacity

    @av_protected_capacity.setter
    def av_protected_capacity(self, av_protected_capacity):
        """Sets the av_protected_capacity of this InlineResponse20068ResponsePool.


        :param av_protected_capacity: The av_protected_capacity of this InlineResponse20068ResponsePool.  # noqa: E501
        :type: float
        """

        self._av_protected_capacity = av_protected_capacity

    @property
    def provisioned_capacity(self):
        """Gets the provisioned_capacity of this InlineResponse20068ResponsePool.  # noqa: E501


        :return: The provisioned_capacity of this InlineResponse20068ResponsePool.  # noqa: E501
        :rtype: float
        """
        return self._provisioned_capacity

    @provisioned_capacity.setter
    def provisioned_capacity(self, provisioned_capacity):
        """Sets the provisioned_capacity of this InlineResponse20068ResponsePool.


        :param provisioned_capacity: The provisioned_capacity of this InlineResponse20068ResponsePool.  # noqa: E501
        :type: float
        """

        self._provisioned_capacity = provisioned_capacity

    @property
    def ssd(self):
        """Gets the ssd of this InlineResponse20068ResponsePool.  # noqa: E501


        :return: The ssd of this InlineResponse20068ResponsePool.  # noqa: E501
        :rtype: InlineResponse20068ResponsePoolSsd
        """
        return self._ssd

    @ssd.setter
    def ssd(self, ssd):
        """Sets the ssd of this InlineResponse20068ResponsePool.


        :param ssd: The ssd of this InlineResponse20068ResponsePool.  # noqa: E501
        :type: InlineResponse20068ResponsePoolSsd
        """

        self._ssd = ssd

    @property
    def hdd(self):
        """Gets the hdd of this InlineResponse20068ResponsePool.  # noqa: E501


        :return: The hdd of this InlineResponse20068ResponsePool.  # noqa: E501
        :rtype: InlineResponse20068ResponsePoolSsd
        """
        return self._hdd

    @hdd.setter
    def hdd(self, hdd):
        """Sets the hdd of this InlineResponse20068ResponsePool.


        :param hdd: The hdd of this InlineResponse20068ResponsePool.  # noqa: E501
        :type: InlineResponse20068ResponsePoolSsd
        """

        self._hdd = hdd

    @property
    def obs(self):
        """Gets the obs of this InlineResponse20068ResponsePool.  # noqa: E501


        :return: The obs of this InlineResponse20068ResponsePool.  # noqa: E501
        :rtype: InlineResponse20068ResponsePoolSsd
        """
        return self._obs

    @obs.setter
    def obs(self, obs):
        """Sets the obs of this InlineResponse20068ResponsePool.


        :param obs: The obs of this InlineResponse20068ResponsePool.  # noqa: E501
        :type: InlineResponse20068ResponsePoolSsd
        """

        self._obs = obs

    @property
    def antivirus(self):
        """Gets the antivirus of this InlineResponse20068ResponsePool.  # noqa: E501


        :return: The antivirus of this InlineResponse20068ResponsePool.  # noqa: E501
        :rtype: str
        """
        return self._antivirus

    @antivirus.setter
    def antivirus(self, antivirus):
        """Sets the antivirus of this InlineResponse20068ResponsePool.


        :param antivirus: The antivirus of this InlineResponse20068ResponsePool.  # noqa: E501
        :type: str
        """

        self._antivirus = antivirus

    @property
    def maintenance_mode(self):
        """Gets the maintenance_mode of this InlineResponse20068ResponsePool.  # noqa: E501


        :return: The maintenance_mode of this InlineResponse20068ResponsePool.  # noqa: E501
        :rtype: str
        """
        return self._maintenance_mode

    @maintenance_mode.setter
    def maintenance_mode(self, maintenance_mode):
        """Sets the maintenance_mode of this InlineResponse20068ResponsePool.


        :param maintenance_mode: The maintenance_mode of this InlineResponse20068ResponsePool.  # noqa: E501
        :type: str
        """

        self._maintenance_mode = maintenance_mode

    @property
    def cool_off_hours(self):
        """Gets the cool_off_hours of this InlineResponse20068ResponsePool.  # noqa: E501


        :return: The cool_off_hours of this InlineResponse20068ResponsePool.  # noqa: E501
        :rtype: int
        """
        return self._cool_off_hours

    @cool_off_hours.setter
    def cool_off_hours(self, cool_off_hours):
        """Sets the cool_off_hours of this InlineResponse20068ResponsePool.


        :param cool_off_hours: The cool_off_hours of this InlineResponse20068ResponsePool.  # noqa: E501
        :type: int
        """

        self._cool_off_hours = cool_off_hours

    @property
    def thresholds(self):
        """Gets the thresholds of this InlineResponse20068ResponsePool.  # noqa: E501


        :return: The thresholds of this InlineResponse20068ResponsePool.  # noqa: E501
        :rtype: str
        """
        return self._thresholds

    @thresholds.setter
    def thresholds(self, thresholds):
        """Sets the thresholds of this InlineResponse20068ResponsePool.


        :param thresholds: The thresholds of this InlineResponse20068ResponsePool.  # noqa: E501
        :type: str
        """

        self._thresholds = thresholds

    @property
    def comment(self):
        """Gets the comment of this InlineResponse20068ResponsePool.  # noqa: E501


        :return: The comment of this InlineResponse20068ResponsePool.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this InlineResponse20068ResponsePool.


        :param comment: The comment of this InlineResponse20068ResponsePool.  # noqa: E501
        :type: str
        """

        self._comment = comment

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20068ResponsePool, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20068ResponsePool):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20068ResponsePool):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class InlineResponse20038Nodes(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'name': 'str',
        'status': 'str',
        'absent': 'bool',
        'information': 'InlineResponse20038Information',
        'nic_information': 'list[InlineResponse20038NicInformation]',
        'services': 'list[InlineResponse20038Services]',
        'resources': 'InlineResponse20038Resources',
        'drives': 'list[InlineResponse20038Drives]',
        'fault_domain': 'str',
        'master': 'bool',
        'slave': 'bool',
        'faulty_services': 'list[str]',
        'config_role': 'str',
        'macs': 'InlineResponse20038Macs',
        'ips': 'InlineResponse20038Ips',
        'virtual_controllers': 'int',
        'license': 'InlineResponse20038License'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'status': 'status',
        'absent': 'absent',
        'information': 'information',
        'nic_information': 'nic_information',
        'services': 'services',
        'resources': 'resources',
        'drives': 'drives',
        'fault_domain': 'fault_domain',
        'master': 'master',
        'slave': 'slave',
        'faulty_services': 'faulty_services',
        'config_role': 'config_role',
        'macs': 'macs',
        'ips': 'ips',
        'virtual_controllers': 'virtual_controllers',
        'license': 'license'
    }

    def __init__(self, id=None, name=None, status=None, absent=None, information=None, nic_information=None, services=None, resources=None, drives=None, fault_domain=None, master=None, slave=None, faulty_services=None, config_role=None, macs=None, ips=None, virtual_controllers=None, license=None, _configuration=None):  # noqa: E501
        """InlineResponse20038Nodes - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._name = None
        self._status = None
        self._absent = None
        self._information = None
        self._nic_information = None
        self._services = None
        self._resources = None
        self._drives = None
        self._fault_domain = None
        self._master = None
        self._slave = None
        self._faulty_services = None
        self._config_role = None
        self._macs = None
        self._ips = None
        self._virtual_controllers = None
        self._license = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if status is not None:
            self.status = status
        if absent is not None:
            self.absent = absent
        if information is not None:
            self.information = information
        if nic_information is not None:
            self.nic_information = nic_information
        if services is not None:
            self.services = services
        if resources is not None:
            self.resources = resources
        if drives is not None:
            self.drives = drives
        if fault_domain is not None:
            self.fault_domain = fault_domain
        if master is not None:
            self.master = master
        if slave is not None:
            self.slave = slave
        if faulty_services is not None:
            self.faulty_services = faulty_services
        if config_role is not None:
            self.config_role = config_role
        if macs is not None:
            self.macs = macs
        if ips is not None:
            self.ips = ips
        if virtual_controllers is not None:
            self.virtual_controllers = virtual_controllers
        if license is not None:
            self.license = license

    @property
    def id(self):
        """Gets the id of this InlineResponse20038Nodes.  # noqa: E501


        :return: The id of this InlineResponse20038Nodes.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InlineResponse20038Nodes.


        :param id: The id of this InlineResponse20038Nodes.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this InlineResponse20038Nodes.  # noqa: E501


        :return: The name of this InlineResponse20038Nodes.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse20038Nodes.


        :param name: The name of this InlineResponse20038Nodes.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def status(self):
        """Gets the status of this InlineResponse20038Nodes.  # noqa: E501


        :return: The status of this InlineResponse20038Nodes.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this InlineResponse20038Nodes.


        :param status: The status of this InlineResponse20038Nodes.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def absent(self):
        """Gets the absent of this InlineResponse20038Nodes.  # noqa: E501


        :return: The absent of this InlineResponse20038Nodes.  # noqa: E501
        :rtype: bool
        """
        return self._absent

    @absent.setter
    def absent(self, absent):
        """Sets the absent of this InlineResponse20038Nodes.


        :param absent: The absent of this InlineResponse20038Nodes.  # noqa: E501
        :type: bool
        """

        self._absent = absent

    @property
    def information(self):
        """Gets the information of this InlineResponse20038Nodes.  # noqa: E501


        :return: The information of this InlineResponse20038Nodes.  # noqa: E501
        :rtype: InlineResponse20038Information
        """
        return self._information

    @information.setter
    def information(self, information):
        """Sets the information of this InlineResponse20038Nodes.


        :param information: The information of this InlineResponse20038Nodes.  # noqa: E501
        :type: InlineResponse20038Information
        """

        self._information = information

    @property
    def nic_information(self):
        """Gets the nic_information of this InlineResponse20038Nodes.  # noqa: E501


        :return: The nic_information of this InlineResponse20038Nodes.  # noqa: E501
        :rtype: list[InlineResponse20038NicInformation]
        """
        return self._nic_information

    @nic_information.setter
    def nic_information(self, nic_information):
        """Sets the nic_information of this InlineResponse20038Nodes.


        :param nic_information: The nic_information of this InlineResponse20038Nodes.  # noqa: E501
        :type: list[InlineResponse20038NicInformation]
        """

        self._nic_information = nic_information

    @property
    def services(self):
        """Gets the services of this InlineResponse20038Nodes.  # noqa: E501


        :return: The services of this InlineResponse20038Nodes.  # noqa: E501
        :rtype: list[InlineResponse20038Services]
        """
        return self._services

    @services.setter
    def services(self, services):
        """Sets the services of this InlineResponse20038Nodes.


        :param services: The services of this InlineResponse20038Nodes.  # noqa: E501
        :type: list[InlineResponse20038Services]
        """

        self._services = services

    @property
    def resources(self):
        """Gets the resources of this InlineResponse20038Nodes.  # noqa: E501


        :return: The resources of this InlineResponse20038Nodes.  # noqa: E501
        :rtype: InlineResponse20038Resources
        """
        return self._resources

    @resources.setter
    def resources(self, resources):
        """Sets the resources of this InlineResponse20038Nodes.


        :param resources: The resources of this InlineResponse20038Nodes.  # noqa: E501
        :type: InlineResponse20038Resources
        """

        self._resources = resources

    @property
    def drives(self):
        """Gets the drives of this InlineResponse20038Nodes.  # noqa: E501


        :return: The drives of this InlineResponse20038Nodes.  # noqa: E501
        :rtype: list[InlineResponse20038Drives]
        """
        return self._drives

    @drives.setter
    def drives(self, drives):
        """Sets the drives of this InlineResponse20038Nodes.


        :param drives: The drives of this InlineResponse20038Nodes.  # noqa: E501
        :type: list[InlineResponse20038Drives]
        """

        self._drives = drives

    @property
    def fault_domain(self):
        """Gets the fault_domain of this InlineResponse20038Nodes.  # noqa: E501


        :return: The fault_domain of this InlineResponse20038Nodes.  # noqa: E501
        :rtype: str
        """
        return self._fault_domain

    @fault_domain.setter
    def fault_domain(self, fault_domain):
        """Sets the fault_domain of this InlineResponse20038Nodes.


        :param fault_domain: The fault_domain of this InlineResponse20038Nodes.  # noqa: E501
        :type: str
        """

        self._fault_domain = fault_domain

    @property
    def master(self):
        """Gets the master of this InlineResponse20038Nodes.  # noqa: E501


        :return: The master of this InlineResponse20038Nodes.  # noqa: E501
        :rtype: bool
        """
        return self._master

    @master.setter
    def master(self, master):
        """Sets the master of this InlineResponse20038Nodes.


        :param master: The master of this InlineResponse20038Nodes.  # noqa: E501
        :type: bool
        """

        self._master = master

    @property
    def slave(self):
        """Gets the slave of this InlineResponse20038Nodes.  # noqa: E501


        :return: The slave of this InlineResponse20038Nodes.  # noqa: E501
        :rtype: bool
        """
        return self._slave

    @slave.setter
    def slave(self, slave):
        """Sets the slave of this InlineResponse20038Nodes.


        :param slave: The slave of this InlineResponse20038Nodes.  # noqa: E501
        :type: bool
        """

        self._slave = slave

    @property
    def faulty_services(self):
        """Gets the faulty_services of this InlineResponse20038Nodes.  # noqa: E501


        :return: The faulty_services of this InlineResponse20038Nodes.  # noqa: E501
        :rtype: list[str]
        """
        return self._faulty_services

    @faulty_services.setter
    def faulty_services(self, faulty_services):
        """Sets the faulty_services of this InlineResponse20038Nodes.


        :param faulty_services: The faulty_services of this InlineResponse20038Nodes.  # noqa: E501
        :type: list[str]
        """

        self._faulty_services = faulty_services

    @property
    def config_role(self):
        """Gets the config_role of this InlineResponse20038Nodes.  # noqa: E501


        :return: The config_role of this InlineResponse20038Nodes.  # noqa: E501
        :rtype: str
        """
        return self._config_role

    @config_role.setter
    def config_role(self, config_role):
        """Sets the config_role of this InlineResponse20038Nodes.


        :param config_role: The config_role of this InlineResponse20038Nodes.  # noqa: E501
        :type: str
        """

        self._config_role = config_role

    @property
    def macs(self):
        """Gets the macs of this InlineResponse20038Nodes.  # noqa: E501


        :return: The macs of this InlineResponse20038Nodes.  # noqa: E501
        :rtype: InlineResponse20038Macs
        """
        return self._macs

    @macs.setter
    def macs(self, macs):
        """Sets the macs of this InlineResponse20038Nodes.


        :param macs: The macs of this InlineResponse20038Nodes.  # noqa: E501
        :type: InlineResponse20038Macs
        """

        self._macs = macs

    @property
    def ips(self):
        """Gets the ips of this InlineResponse20038Nodes.  # noqa: E501


        :return: The ips of this InlineResponse20038Nodes.  # noqa: E501
        :rtype: InlineResponse20038Ips
        """
        return self._ips

    @ips.setter
    def ips(self, ips):
        """Sets the ips of this InlineResponse20038Nodes.


        :param ips: The ips of this InlineResponse20038Nodes.  # noqa: E501
        :type: InlineResponse20038Ips
        """

        self._ips = ips

    @property
    def virtual_controllers(self):
        """Gets the virtual_controllers of this InlineResponse20038Nodes.  # noqa: E501


        :return: The virtual_controllers of this InlineResponse20038Nodes.  # noqa: E501
        :rtype: int
        """
        return self._virtual_controllers

    @virtual_controllers.setter
    def virtual_controllers(self, virtual_controllers):
        """Sets the virtual_controllers of this InlineResponse20038Nodes.


        :param virtual_controllers: The virtual_controllers of this InlineResponse20038Nodes.  # noqa: E501
        :type: int
        """

        self._virtual_controllers = virtual_controllers

    @property
    def license(self):
        """Gets the license of this InlineResponse20038Nodes.  # noqa: E501


        :return: The license of this InlineResponse20038Nodes.  # noqa: E501
        :rtype: InlineResponse20038License
        """
        return self._license

    @license.setter
    def license(self, license):
        """Sets the license of this InlineResponse20038Nodes.


        :param license: The license of this InlineResponse20038Nodes.  # noqa: E501
        :type: InlineResponse20038License
        """

        self._license = license

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20038Nodes, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20038Nodes):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20038Nodes):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara Provisioning Portal API

     # Overview  This document outlines the methods available for creation and high-level administration of Zadara Storage VPSAs via a Zadara Storage Provisioning Portal. This API supports form-encoded requests, and can return either JSON or XML responses.  ## Endpoint  The base URL for the requests is the Provisioning Portal URL you created your VPSA through - for example: https://manage.zadarastorage.com/, and all APIs will be prefixed with /api as noted in the documentation below.  ## Authentication  To use this API, an authentication token is required. The API for retrieving this token can be found below in the Authentication section. You may pass this token in requests either via the the X-Token header or via basic authentication (base64 encoded) in Authorization header.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from ProvisioningPortal.configuration import Configuration


class InlineResponse2001Data(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'uuid': 'str',
        'enabled': 'str',
        'app_engines': 'list[InlineResponse2001AppEngines]',
        'nova_url': 'str',
        'auth_url': 'str',
        'keystone_url': 'str',
        'glance_url': 'str',
        'drive_types': 'list[InlineResponse2001DriveTypes]',
        'engine_types': 'list[InlineResponse2001EngineTypes]',
        'fibre_channel': 'InlineResponse2001FibreChannel',
        'flash_cache': 'InlineResponse2001FlashCache',
        'minimum_drives': 'int',
        'supports_app_engines': 'bool',
        'zios': 'InlineResponse2001FibreChannel',
        'zones': 'list[InlineResponse2001Zones]',
        'vpsa_zone_group_storage_policy_types': 'InlineResponse2001VpsazoneGroupStoragePolicyTypes'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'uuid': 'uuid',
        'enabled': 'enabled',
        'app_engines': 'app_engines',
        'nova_url': 'nova_url',
        'auth_url': 'auth_url',
        'keystone_url': 'keystone_url',
        'glance_url': 'glance_url',
        'drive_types': 'drive_types',
        'engine_types': 'engine_types',
        'fibre_channel': 'fibre_channel',
        'flash_cache': 'flash_cache',
        'minimum_drives': 'minimum_drives',
        'supports_app_engines': 'supports_app_engines',
        'zios': 'zios',
        'zones': 'zones',
        'vpsa_zone_group_storage_policy_types': 'vpsa-zone_group_storage_policy_types'
    }

    def __init__(self, id=None, name=None, uuid=None, enabled=None, app_engines=None, nova_url=None, auth_url=None, keystone_url=None, glance_url=None, drive_types=None, engine_types=None, fibre_channel=None, flash_cache=None, minimum_drives=None, supports_app_engines=None, zios=None, zones=None, vpsa_zone_group_storage_policy_types=None, _configuration=None):  # noqa: E501
        """InlineResponse2001Data - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._name = None
        self._uuid = None
        self._enabled = None
        self._app_engines = None
        self._nova_url = None
        self._auth_url = None
        self._keystone_url = None
        self._glance_url = None
        self._drive_types = None
        self._engine_types = None
        self._fibre_channel = None
        self._flash_cache = None
        self._minimum_drives = None
        self._supports_app_engines = None
        self._zios = None
        self._zones = None
        self._vpsa_zone_group_storage_policy_types = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if uuid is not None:
            self.uuid = uuid
        if enabled is not None:
            self.enabled = enabled
        if app_engines is not None:
            self.app_engines = app_engines
        if nova_url is not None:
            self.nova_url = nova_url
        if auth_url is not None:
            self.auth_url = auth_url
        if keystone_url is not None:
            self.keystone_url = keystone_url
        if glance_url is not None:
            self.glance_url = glance_url
        if drive_types is not None:
            self.drive_types = drive_types
        if engine_types is not None:
            self.engine_types = engine_types
        if fibre_channel is not None:
            self.fibre_channel = fibre_channel
        if flash_cache is not None:
            self.flash_cache = flash_cache
        if minimum_drives is not None:
            self.minimum_drives = minimum_drives
        if supports_app_engines is not None:
            self.supports_app_engines = supports_app_engines
        if zios is not None:
            self.zios = zios
        if zones is not None:
            self.zones = zones
        if vpsa_zone_group_storage_policy_types is not None:
            self.vpsa_zone_group_storage_policy_types = vpsa_zone_group_storage_policy_types

    @property
    def id(self):
        """Gets the id of this InlineResponse2001Data.  # noqa: E501


        :return: The id of this InlineResponse2001Data.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InlineResponse2001Data.


        :param id: The id of this InlineResponse2001Data.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this InlineResponse2001Data.  # noqa: E501


        :return: The name of this InlineResponse2001Data.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse2001Data.


        :param name: The name of this InlineResponse2001Data.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def uuid(self):
        """Gets the uuid of this InlineResponse2001Data.  # noqa: E501


        :return: The uuid of this InlineResponse2001Data.  # noqa: E501
        :rtype: str
        """
        return self._uuid

    @uuid.setter
    def uuid(self, uuid):
        """Sets the uuid of this InlineResponse2001Data.


        :param uuid: The uuid of this InlineResponse2001Data.  # noqa: E501
        :type: str
        """

        self._uuid = uuid

    @property
    def enabled(self):
        """Gets the enabled of this InlineResponse2001Data.  # noqa: E501


        :return: The enabled of this InlineResponse2001Data.  # noqa: E501
        :rtype: str
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this InlineResponse2001Data.


        :param enabled: The enabled of this InlineResponse2001Data.  # noqa: E501
        :type: str
        """

        self._enabled = enabled

    @property
    def app_engines(self):
        """Gets the app_engines of this InlineResponse2001Data.  # noqa: E501


        :return: The app_engines of this InlineResponse2001Data.  # noqa: E501
        :rtype: list[InlineResponse2001AppEngines]
        """
        return self._app_engines

    @app_engines.setter
    def app_engines(self, app_engines):
        """Sets the app_engines of this InlineResponse2001Data.


        :param app_engines: The app_engines of this InlineResponse2001Data.  # noqa: E501
        :type: list[InlineResponse2001AppEngines]
        """

        self._app_engines = app_engines

    @property
    def nova_url(self):
        """Gets the nova_url of this InlineResponse2001Data.  # noqa: E501


        :return: The nova_url of this InlineResponse2001Data.  # noqa: E501
        :rtype: str
        """
        return self._nova_url

    @nova_url.setter
    def nova_url(self, nova_url):
        """Sets the nova_url of this InlineResponse2001Data.


        :param nova_url: The nova_url of this InlineResponse2001Data.  # noqa: E501
        :type: str
        """

        self._nova_url = nova_url

    @property
    def auth_url(self):
        """Gets the auth_url of this InlineResponse2001Data.  # noqa: E501


        :return: The auth_url of this InlineResponse2001Data.  # noqa: E501
        :rtype: str
        """
        return self._auth_url

    @auth_url.setter
    def auth_url(self, auth_url):
        """Sets the auth_url of this InlineResponse2001Data.


        :param auth_url: The auth_url of this InlineResponse2001Data.  # noqa: E501
        :type: str
        """

        self._auth_url = auth_url

    @property
    def keystone_url(self):
        """Gets the keystone_url of this InlineResponse2001Data.  # noqa: E501


        :return: The keystone_url of this InlineResponse2001Data.  # noqa: E501
        :rtype: str
        """
        return self._keystone_url

    @keystone_url.setter
    def keystone_url(self, keystone_url):
        """Sets the keystone_url of this InlineResponse2001Data.


        :param keystone_url: The keystone_url of this InlineResponse2001Data.  # noqa: E501
        :type: str
        """

        self._keystone_url = keystone_url

    @property
    def glance_url(self):
        """Gets the glance_url of this InlineResponse2001Data.  # noqa: E501


        :return: The glance_url of this InlineResponse2001Data.  # noqa: E501
        :rtype: str
        """
        return self._glance_url

    @glance_url.setter
    def glance_url(self, glance_url):
        """Sets the glance_url of this InlineResponse2001Data.


        :param glance_url: The glance_url of this InlineResponse2001Data.  # noqa: E501
        :type: str
        """

        self._glance_url = glance_url

    @property
    def drive_types(self):
        """Gets the drive_types of this InlineResponse2001Data.  # noqa: E501


        :return: The drive_types of this InlineResponse2001Data.  # noqa: E501
        :rtype: list[InlineResponse2001DriveTypes]
        """
        return self._drive_types

    @drive_types.setter
    def drive_types(self, drive_types):
        """Sets the drive_types of this InlineResponse2001Data.


        :param drive_types: The drive_types of this InlineResponse2001Data.  # noqa: E501
        :type: list[InlineResponse2001DriveTypes]
        """

        self._drive_types = drive_types

    @property
    def engine_types(self):
        """Gets the engine_types of this InlineResponse2001Data.  # noqa: E501


        :return: The engine_types of this InlineResponse2001Data.  # noqa: E501
        :rtype: list[InlineResponse2001EngineTypes]
        """
        return self._engine_types

    @engine_types.setter
    def engine_types(self, engine_types):
        """Sets the engine_types of this InlineResponse2001Data.


        :param engine_types: The engine_types of this InlineResponse2001Data.  # noqa: E501
        :type: list[InlineResponse2001EngineTypes]
        """

        self._engine_types = engine_types

    @property
    def fibre_channel(self):
        """Gets the fibre_channel of this InlineResponse2001Data.  # noqa: E501


        :return: The fibre_channel of this InlineResponse2001Data.  # noqa: E501
        :rtype: InlineResponse2001FibreChannel
        """
        return self._fibre_channel

    @fibre_channel.setter
    def fibre_channel(self, fibre_channel):
        """Sets the fibre_channel of this InlineResponse2001Data.


        :param fibre_channel: The fibre_channel of this InlineResponse2001Data.  # noqa: E501
        :type: InlineResponse2001FibreChannel
        """

        self._fibre_channel = fibre_channel

    @property
    def flash_cache(self):
        """Gets the flash_cache of this InlineResponse2001Data.  # noqa: E501


        :return: The flash_cache of this InlineResponse2001Data.  # noqa: E501
        :rtype: InlineResponse2001FlashCache
        """
        return self._flash_cache

    @flash_cache.setter
    def flash_cache(self, flash_cache):
        """Sets the flash_cache of this InlineResponse2001Data.


        :param flash_cache: The flash_cache of this InlineResponse2001Data.  # noqa: E501
        :type: InlineResponse2001FlashCache
        """

        self._flash_cache = flash_cache

    @property
    def minimum_drives(self):
        """Gets the minimum_drives of this InlineResponse2001Data.  # noqa: E501


        :return: The minimum_drives of this InlineResponse2001Data.  # noqa: E501
        :rtype: int
        """
        return self._minimum_drives

    @minimum_drives.setter
    def minimum_drives(self, minimum_drives):
        """Sets the minimum_drives of this InlineResponse2001Data.


        :param minimum_drives: The minimum_drives of this InlineResponse2001Data.  # noqa: E501
        :type: int
        """

        self._minimum_drives = minimum_drives

    @property
    def supports_app_engines(self):
        """Gets the supports_app_engines of this InlineResponse2001Data.  # noqa: E501


        :return: The supports_app_engines of this InlineResponse2001Data.  # noqa: E501
        :rtype: bool
        """
        return self._supports_app_engines

    @supports_app_engines.setter
    def supports_app_engines(self, supports_app_engines):
        """Sets the supports_app_engines of this InlineResponse2001Data.


        :param supports_app_engines: The supports_app_engines of this InlineResponse2001Data.  # noqa: E501
        :type: bool
        """

        self._supports_app_engines = supports_app_engines

    @property
    def zios(self):
        """Gets the zios of this InlineResponse2001Data.  # noqa: E501


        :return: The zios of this InlineResponse2001Data.  # noqa: E501
        :rtype: InlineResponse2001FibreChannel
        """
        return self._zios

    @zios.setter
    def zios(self, zios):
        """Sets the zios of this InlineResponse2001Data.


        :param zios: The zios of this InlineResponse2001Data.  # noqa: E501
        :type: InlineResponse2001FibreChannel
        """

        self._zios = zios

    @property
    def zones(self):
        """Gets the zones of this InlineResponse2001Data.  # noqa: E501


        :return: The zones of this InlineResponse2001Data.  # noqa: E501
        :rtype: list[InlineResponse2001Zones]
        """
        return self._zones

    @zones.setter
    def zones(self, zones):
        """Sets the zones of this InlineResponse2001Data.


        :param zones: The zones of this InlineResponse2001Data.  # noqa: E501
        :type: list[InlineResponse2001Zones]
        """

        self._zones = zones

    @property
    def vpsa_zone_group_storage_policy_types(self):
        """Gets the vpsa_zone_group_storage_policy_types of this InlineResponse2001Data.  # noqa: E501


        :return: The vpsa_zone_group_storage_policy_types of this InlineResponse2001Data.  # noqa: E501
        :rtype: InlineResponse2001VpsazoneGroupStoragePolicyTypes
        """
        return self._vpsa_zone_group_storage_policy_types

    @vpsa_zone_group_storage_policy_types.setter
    def vpsa_zone_group_storage_policy_types(self, vpsa_zone_group_storage_policy_types):
        """Sets the vpsa_zone_group_storage_policy_types of this InlineResponse2001Data.


        :param vpsa_zone_group_storage_policy_types: The vpsa_zone_group_storage_policy_types of this InlineResponse2001Data.  # noqa: E501
        :type: InlineResponse2001VpsazoneGroupStoragePolicyTypes
        """

        self._vpsa_zone_group_storage_policy_types = vpsa_zone_group_storage_policy_types

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse2001Data, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse2001Data):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse2001Data):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class InlineResponse20017ResponseVcontrollers(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'display_name': 'str',
        'index': 'str',
        'state': 'str',
        'target': 'str',
        'iscsi_ip': 'str',
        'iscsi_ipv6': 'str',
        'mgmt_ip': 'str',
        'mgmt_ipv6': 'str',
        'software_ver': 'str',
        'heartbeat1': 'str',
        'heartbeat2': 'str',
        'vpsa_chap_user': 'str',
        'vpsa_chap_secret': 'str',
        'host_chap_user': 'str',
        'host_chap_secret': 'str',
        'ike_psk': 'str',
        'encryption_password_set': 'str',
        'is_encryption_active': 'str',
        'sn_host': 'str',
        'cache_size': 'int',
        'cpu_usage_alert': 'int',
        'mem_usage_alert': 'int',
        'cpu_docker_usage_alert': 'int',
        'mem_docker_usage_alert': 'int',
        'recycle_bin': 'str',
        'dm_concurrency_level': 'int',
        'nfs4_disable_idmapping': 'str',
        'raid_read_mode': 'str',
        'allocation_zone_name': 'str',
        'allocation_zone_display_name': 'str',
        'smb_unix_charset': 'str',
        'smb_dos_charset': 'str',
        'vpsa_uuid': 'str',
        'sod_end_time': 'str',
        'wwpn_count': 'int',
        'integrity_status': 'str',
        'iser_support': 'str'
    }

    attribute_map = {
        'name': 'name',
        'display_name': 'display_name',
        'index': 'index',
        'state': 'state',
        'target': 'target',
        'iscsi_ip': 'iscsi_ip',
        'iscsi_ipv6': 'iscsi_ipv6',
        'mgmt_ip': 'mgmt_ip',
        'mgmt_ipv6': 'mgmt_ipv6',
        'software_ver': 'software_ver',
        'heartbeat1': 'heartbeat1',
        'heartbeat2': 'heartbeat2',
        'vpsa_chap_user': 'vpsa_chap_user',
        'vpsa_chap_secret': 'vpsa_chap_secret',
        'host_chap_user': 'host_chap_user',
        'host_chap_secret': 'host_chap_secret',
        'ike_psk': 'ike_psk',
        'encryption_password_set': 'encryption_password_set',
        'is_encryption_active': 'is_encryption_active',
        'sn_host': 'sn_host',
        'cache_size': 'cache_size',
        'cpu_usage_alert': 'cpu_usage_alert',
        'mem_usage_alert': 'mem_usage_alert',
        'cpu_docker_usage_alert': 'cpu_docker_usage_alert',
        'mem_docker_usage_alert': 'mem_docker_usage_alert',
        'recycle_bin': 'recycle_bin',
        'dm_concurrency_level': 'dm_concurrency_level',
        'nfs4_disable_idmapping': 'nfs4_disable_idmapping',
        'raid_read_mode': 'raid_read_mode',
        'allocation_zone_name': 'allocation-zone_name',
        'allocation_zone_display_name': 'allocation-zone_display_name',
        'smb_unix_charset': 'smb_unix_charset',
        'smb_dos_charset': 'smb_dos_charset',
        'vpsa_uuid': 'vpsa_uuid',
        'sod_end_time': 'sod_end_time',
        'wwpn_count': 'wwpn_count',
        'integrity_status': 'integrity_status',
        'iser_support': 'iser_support'
    }

    def __init__(self, name=None, display_name=None, index=None, state=None, target=None, iscsi_ip=None, iscsi_ipv6=None, mgmt_ip=None, mgmt_ipv6=None, software_ver=None, heartbeat1=None, heartbeat2=None, vpsa_chap_user=None, vpsa_chap_secret=None, host_chap_user=None, host_chap_secret=None, ike_psk=None, encryption_password_set=None, is_encryption_active=None, sn_host=None, cache_size=None, cpu_usage_alert=None, mem_usage_alert=None, cpu_docker_usage_alert=None, mem_docker_usage_alert=None, recycle_bin=None, dm_concurrency_level=None, nfs4_disable_idmapping=None, raid_read_mode=None, allocation_zone_name=None, allocation_zone_display_name=None, smb_unix_charset=None, smb_dos_charset=None, vpsa_uuid=None, sod_end_time=None, wwpn_count=None, integrity_status=None, iser_support=None, _configuration=None):  # noqa: E501
        """InlineResponse20017ResponseVcontrollers - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._display_name = None
        self._index = None
        self._state = None
        self._target = None
        self._iscsi_ip = None
        self._iscsi_ipv6 = None
        self._mgmt_ip = None
        self._mgmt_ipv6 = None
        self._software_ver = None
        self._heartbeat1 = None
        self._heartbeat2 = None
        self._vpsa_chap_user = None
        self._vpsa_chap_secret = None
        self._host_chap_user = None
        self._host_chap_secret = None
        self._ike_psk = None
        self._encryption_password_set = None
        self._is_encryption_active = None
        self._sn_host = None
        self._cache_size = None
        self._cpu_usage_alert = None
        self._mem_usage_alert = None
        self._cpu_docker_usage_alert = None
        self._mem_docker_usage_alert = None
        self._recycle_bin = None
        self._dm_concurrency_level = None
        self._nfs4_disable_idmapping = None
        self._raid_read_mode = None
        self._allocation_zone_name = None
        self._allocation_zone_display_name = None
        self._smb_unix_charset = None
        self._smb_dos_charset = None
        self._vpsa_uuid = None
        self._sod_end_time = None
        self._wwpn_count = None
        self._integrity_status = None
        self._iser_support = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if display_name is not None:
            self.display_name = display_name
        if index is not None:
            self.index = index
        if state is not None:
            self.state = state
        if target is not None:
            self.target = target
        if iscsi_ip is not None:
            self.iscsi_ip = iscsi_ip
        if iscsi_ipv6 is not None:
            self.iscsi_ipv6 = iscsi_ipv6
        if mgmt_ip is not None:
            self.mgmt_ip = mgmt_ip
        if mgmt_ipv6 is not None:
            self.mgmt_ipv6 = mgmt_ipv6
        if software_ver is not None:
            self.software_ver = software_ver
        if heartbeat1 is not None:
            self.heartbeat1 = heartbeat1
        if heartbeat2 is not None:
            self.heartbeat2 = heartbeat2
        if vpsa_chap_user is not None:
            self.vpsa_chap_user = vpsa_chap_user
        if vpsa_chap_secret is not None:
            self.vpsa_chap_secret = vpsa_chap_secret
        if host_chap_user is not None:
            self.host_chap_user = host_chap_user
        if host_chap_secret is not None:
            self.host_chap_secret = host_chap_secret
        if ike_psk is not None:
            self.ike_psk = ike_psk
        if encryption_password_set is not None:
            self.encryption_password_set = encryption_password_set
        if is_encryption_active is not None:
            self.is_encryption_active = is_encryption_active
        if sn_host is not None:
            self.sn_host = sn_host
        if cache_size is not None:
            self.cache_size = cache_size
        if cpu_usage_alert is not None:
            self.cpu_usage_alert = cpu_usage_alert
        if mem_usage_alert is not None:
            self.mem_usage_alert = mem_usage_alert
        if cpu_docker_usage_alert is not None:
            self.cpu_docker_usage_alert = cpu_docker_usage_alert
        if mem_docker_usage_alert is not None:
            self.mem_docker_usage_alert = mem_docker_usage_alert
        if recycle_bin is not None:
            self.recycle_bin = recycle_bin
        if dm_concurrency_level is not None:
            self.dm_concurrency_level = dm_concurrency_level
        if nfs4_disable_idmapping is not None:
            self.nfs4_disable_idmapping = nfs4_disable_idmapping
        if raid_read_mode is not None:
            self.raid_read_mode = raid_read_mode
        if allocation_zone_name is not None:
            self.allocation_zone_name = allocation_zone_name
        if allocation_zone_display_name is not None:
            self.allocation_zone_display_name = allocation_zone_display_name
        if smb_unix_charset is not None:
            self.smb_unix_charset = smb_unix_charset
        if smb_dos_charset is not None:
            self.smb_dos_charset = smb_dos_charset
        if vpsa_uuid is not None:
            self.vpsa_uuid = vpsa_uuid
        if sod_end_time is not None:
            self.sod_end_time = sod_end_time
        if wwpn_count is not None:
            self.wwpn_count = wwpn_count
        if integrity_status is not None:
            self.integrity_status = integrity_status
        if iser_support is not None:
            self.iser_support = iser_support

    @property
    def name(self):
        """Gets the name of this InlineResponse20017ResponseVcontrollers.  # noqa: E501


        :return: The name of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse20017ResponseVcontrollers.


        :param name: The name of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def display_name(self):
        """Gets the display_name of this InlineResponse20017ResponseVcontrollers.  # noqa: E501


        :return: The display_name of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this InlineResponse20017ResponseVcontrollers.


        :param display_name: The display_name of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def index(self):
        """Gets the index of this InlineResponse20017ResponseVcontrollers.  # noqa: E501


        :return: The index of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :rtype: str
        """
        return self._index

    @index.setter
    def index(self, index):
        """Sets the index of this InlineResponse20017ResponseVcontrollers.


        :param index: The index of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :type: str
        """

        self._index = index

    @property
    def state(self):
        """Gets the state of this InlineResponse20017ResponseVcontrollers.  # noqa: E501


        :return: The state of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this InlineResponse20017ResponseVcontrollers.


        :param state: The state of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def target(self):
        """Gets the target of this InlineResponse20017ResponseVcontrollers.  # noqa: E501


        :return: The target of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :rtype: str
        """
        return self._target

    @target.setter
    def target(self, target):
        """Sets the target of this InlineResponse20017ResponseVcontrollers.


        :param target: The target of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :type: str
        """

        self._target = target

    @property
    def iscsi_ip(self):
        """Gets the iscsi_ip of this InlineResponse20017ResponseVcontrollers.  # noqa: E501


        :return: The iscsi_ip of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :rtype: str
        """
        return self._iscsi_ip

    @iscsi_ip.setter
    def iscsi_ip(self, iscsi_ip):
        """Sets the iscsi_ip of this InlineResponse20017ResponseVcontrollers.


        :param iscsi_ip: The iscsi_ip of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :type: str
        """

        self._iscsi_ip = iscsi_ip

    @property
    def iscsi_ipv6(self):
        """Gets the iscsi_ipv6 of this InlineResponse20017ResponseVcontrollers.  # noqa: E501


        :return: The iscsi_ipv6 of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :rtype: str
        """
        return self._iscsi_ipv6

    @iscsi_ipv6.setter
    def iscsi_ipv6(self, iscsi_ipv6):
        """Sets the iscsi_ipv6 of this InlineResponse20017ResponseVcontrollers.


        :param iscsi_ipv6: The iscsi_ipv6 of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :type: str
        """

        self._iscsi_ipv6 = iscsi_ipv6

    @property
    def mgmt_ip(self):
        """Gets the mgmt_ip of this InlineResponse20017ResponseVcontrollers.  # noqa: E501


        :return: The mgmt_ip of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :rtype: str
        """
        return self._mgmt_ip

    @mgmt_ip.setter
    def mgmt_ip(self, mgmt_ip):
        """Sets the mgmt_ip of this InlineResponse20017ResponseVcontrollers.


        :param mgmt_ip: The mgmt_ip of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :type: str
        """

        self._mgmt_ip = mgmt_ip

    @property
    def mgmt_ipv6(self):
        """Gets the mgmt_ipv6 of this InlineResponse20017ResponseVcontrollers.  # noqa: E501


        :return: The mgmt_ipv6 of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :rtype: str
        """
        return self._mgmt_ipv6

    @mgmt_ipv6.setter
    def mgmt_ipv6(self, mgmt_ipv6):
        """Sets the mgmt_ipv6 of this InlineResponse20017ResponseVcontrollers.


        :param mgmt_ipv6: The mgmt_ipv6 of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :type: str
        """

        self._mgmt_ipv6 = mgmt_ipv6

    @property
    def software_ver(self):
        """Gets the software_ver of this InlineResponse20017ResponseVcontrollers.  # noqa: E501


        :return: The software_ver of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :rtype: str
        """
        return self._software_ver

    @software_ver.setter
    def software_ver(self, software_ver):
        """Sets the software_ver of this InlineResponse20017ResponseVcontrollers.


        :param software_ver: The software_ver of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :type: str
        """

        self._software_ver = software_ver

    @property
    def heartbeat1(self):
        """Gets the heartbeat1 of this InlineResponse20017ResponseVcontrollers.  # noqa: E501


        :return: The heartbeat1 of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :rtype: str
        """
        return self._heartbeat1

    @heartbeat1.setter
    def heartbeat1(self, heartbeat1):
        """Sets the heartbeat1 of this InlineResponse20017ResponseVcontrollers.


        :param heartbeat1: The heartbeat1 of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :type: str
        """

        self._heartbeat1 = heartbeat1

    @property
    def heartbeat2(self):
        """Gets the heartbeat2 of this InlineResponse20017ResponseVcontrollers.  # noqa: E501


        :return: The heartbeat2 of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :rtype: str
        """
        return self._heartbeat2

    @heartbeat2.setter
    def heartbeat2(self, heartbeat2):
        """Sets the heartbeat2 of this InlineResponse20017ResponseVcontrollers.


        :param heartbeat2: The heartbeat2 of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :type: str
        """

        self._heartbeat2 = heartbeat2

    @property
    def vpsa_chap_user(self):
        """Gets the vpsa_chap_user of this InlineResponse20017ResponseVcontrollers.  # noqa: E501


        :return: The vpsa_chap_user of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :rtype: str
        """
        return self._vpsa_chap_user

    @vpsa_chap_user.setter
    def vpsa_chap_user(self, vpsa_chap_user):
        """Sets the vpsa_chap_user of this InlineResponse20017ResponseVcontrollers.


        :param vpsa_chap_user: The vpsa_chap_user of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :type: str
        """

        self._vpsa_chap_user = vpsa_chap_user

    @property
    def vpsa_chap_secret(self):
        """Gets the vpsa_chap_secret of this InlineResponse20017ResponseVcontrollers.  # noqa: E501


        :return: The vpsa_chap_secret of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :rtype: str
        """
        return self._vpsa_chap_secret

    @vpsa_chap_secret.setter
    def vpsa_chap_secret(self, vpsa_chap_secret):
        """Sets the vpsa_chap_secret of this InlineResponse20017ResponseVcontrollers.


        :param vpsa_chap_secret: The vpsa_chap_secret of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :type: str
        """

        self._vpsa_chap_secret = vpsa_chap_secret

    @property
    def host_chap_user(self):
        """Gets the host_chap_user of this InlineResponse20017ResponseVcontrollers.  # noqa: E501


        :return: The host_chap_user of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :rtype: str
        """
        return self._host_chap_user

    @host_chap_user.setter
    def host_chap_user(self, host_chap_user):
        """Sets the host_chap_user of this InlineResponse20017ResponseVcontrollers.


        :param host_chap_user: The host_chap_user of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :type: str
        """

        self._host_chap_user = host_chap_user

    @property
    def host_chap_secret(self):
        """Gets the host_chap_secret of this InlineResponse20017ResponseVcontrollers.  # noqa: E501


        :return: The host_chap_secret of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :rtype: str
        """
        return self._host_chap_secret

    @host_chap_secret.setter
    def host_chap_secret(self, host_chap_secret):
        """Sets the host_chap_secret of this InlineResponse20017ResponseVcontrollers.


        :param host_chap_secret: The host_chap_secret of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :type: str
        """

        self._host_chap_secret = host_chap_secret

    @property
    def ike_psk(self):
        """Gets the ike_psk of this InlineResponse20017ResponseVcontrollers.  # noqa: E501


        :return: The ike_psk of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :rtype: str
        """
        return self._ike_psk

    @ike_psk.setter
    def ike_psk(self, ike_psk):
        """Sets the ike_psk of this InlineResponse20017ResponseVcontrollers.


        :param ike_psk: The ike_psk of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :type: str
        """

        self._ike_psk = ike_psk

    @property
    def encryption_password_set(self):
        """Gets the encryption_password_set of this InlineResponse20017ResponseVcontrollers.  # noqa: E501


        :return: The encryption_password_set of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :rtype: str
        """
        return self._encryption_password_set

    @encryption_password_set.setter
    def encryption_password_set(self, encryption_password_set):
        """Sets the encryption_password_set of this InlineResponse20017ResponseVcontrollers.


        :param encryption_password_set: The encryption_password_set of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :type: str
        """

        self._encryption_password_set = encryption_password_set

    @property
    def is_encryption_active(self):
        """Gets the is_encryption_active of this InlineResponse20017ResponseVcontrollers.  # noqa: E501


        :return: The is_encryption_active of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :rtype: str
        """
        return self._is_encryption_active

    @is_encryption_active.setter
    def is_encryption_active(self, is_encryption_active):
        """Sets the is_encryption_active of this InlineResponse20017ResponseVcontrollers.


        :param is_encryption_active: The is_encryption_active of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :type: str
        """

        self._is_encryption_active = is_encryption_active

    @property
    def sn_host(self):
        """Gets the sn_host of this InlineResponse20017ResponseVcontrollers.  # noqa: E501


        :return: The sn_host of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :rtype: str
        """
        return self._sn_host

    @sn_host.setter
    def sn_host(self, sn_host):
        """Sets the sn_host of this InlineResponse20017ResponseVcontrollers.


        :param sn_host: The sn_host of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :type: str
        """

        self._sn_host = sn_host

    @property
    def cache_size(self):
        """Gets the cache_size of this InlineResponse20017ResponseVcontrollers.  # noqa: E501


        :return: The cache_size of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :rtype: int
        """
        return self._cache_size

    @cache_size.setter
    def cache_size(self, cache_size):
        """Sets the cache_size of this InlineResponse20017ResponseVcontrollers.


        :param cache_size: The cache_size of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :type: int
        """

        self._cache_size = cache_size

    @property
    def cpu_usage_alert(self):
        """Gets the cpu_usage_alert of this InlineResponse20017ResponseVcontrollers.  # noqa: E501


        :return: The cpu_usage_alert of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :rtype: int
        """
        return self._cpu_usage_alert

    @cpu_usage_alert.setter
    def cpu_usage_alert(self, cpu_usage_alert):
        """Sets the cpu_usage_alert of this InlineResponse20017ResponseVcontrollers.


        :param cpu_usage_alert: The cpu_usage_alert of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :type: int
        """

        self._cpu_usage_alert = cpu_usage_alert

    @property
    def mem_usage_alert(self):
        """Gets the mem_usage_alert of this InlineResponse20017ResponseVcontrollers.  # noqa: E501


        :return: The mem_usage_alert of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :rtype: int
        """
        return self._mem_usage_alert

    @mem_usage_alert.setter
    def mem_usage_alert(self, mem_usage_alert):
        """Sets the mem_usage_alert of this InlineResponse20017ResponseVcontrollers.


        :param mem_usage_alert: The mem_usage_alert of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :type: int
        """

        self._mem_usage_alert = mem_usage_alert

    @property
    def cpu_docker_usage_alert(self):
        """Gets the cpu_docker_usage_alert of this InlineResponse20017ResponseVcontrollers.  # noqa: E501


        :return: The cpu_docker_usage_alert of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :rtype: int
        """
        return self._cpu_docker_usage_alert

    @cpu_docker_usage_alert.setter
    def cpu_docker_usage_alert(self, cpu_docker_usage_alert):
        """Sets the cpu_docker_usage_alert of this InlineResponse20017ResponseVcontrollers.


        :param cpu_docker_usage_alert: The cpu_docker_usage_alert of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :type: int
        """

        self._cpu_docker_usage_alert = cpu_docker_usage_alert

    @property
    def mem_docker_usage_alert(self):
        """Gets the mem_docker_usage_alert of this InlineResponse20017ResponseVcontrollers.  # noqa: E501


        :return: The mem_docker_usage_alert of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :rtype: int
        """
        return self._mem_docker_usage_alert

    @mem_docker_usage_alert.setter
    def mem_docker_usage_alert(self, mem_docker_usage_alert):
        """Sets the mem_docker_usage_alert of this InlineResponse20017ResponseVcontrollers.


        :param mem_docker_usage_alert: The mem_docker_usage_alert of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :type: int
        """

        self._mem_docker_usage_alert = mem_docker_usage_alert

    @property
    def recycle_bin(self):
        """Gets the recycle_bin of this InlineResponse20017ResponseVcontrollers.  # noqa: E501


        :return: The recycle_bin of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :rtype: str
        """
        return self._recycle_bin

    @recycle_bin.setter
    def recycle_bin(self, recycle_bin):
        """Sets the recycle_bin of this InlineResponse20017ResponseVcontrollers.


        :param recycle_bin: The recycle_bin of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :type: str
        """

        self._recycle_bin = recycle_bin

    @property
    def dm_concurrency_level(self):
        """Gets the dm_concurrency_level of this InlineResponse20017ResponseVcontrollers.  # noqa: E501


        :return: The dm_concurrency_level of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :rtype: int
        """
        return self._dm_concurrency_level

    @dm_concurrency_level.setter
    def dm_concurrency_level(self, dm_concurrency_level):
        """Sets the dm_concurrency_level of this InlineResponse20017ResponseVcontrollers.


        :param dm_concurrency_level: The dm_concurrency_level of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :type: int
        """

        self._dm_concurrency_level = dm_concurrency_level

    @property
    def nfs4_disable_idmapping(self):
        """Gets the nfs4_disable_idmapping of this InlineResponse20017ResponseVcontrollers.  # noqa: E501


        :return: The nfs4_disable_idmapping of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :rtype: str
        """
        return self._nfs4_disable_idmapping

    @nfs4_disable_idmapping.setter
    def nfs4_disable_idmapping(self, nfs4_disable_idmapping):
        """Sets the nfs4_disable_idmapping of this InlineResponse20017ResponseVcontrollers.


        :param nfs4_disable_idmapping: The nfs4_disable_idmapping of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :type: str
        """

        self._nfs4_disable_idmapping = nfs4_disable_idmapping

    @property
    def raid_read_mode(self):
        """Gets the raid_read_mode of this InlineResponse20017ResponseVcontrollers.  # noqa: E501


        :return: The raid_read_mode of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :rtype: str
        """
        return self._raid_read_mode

    @raid_read_mode.setter
    def raid_read_mode(self, raid_read_mode):
        """Sets the raid_read_mode of this InlineResponse20017ResponseVcontrollers.


        :param raid_read_mode: The raid_read_mode of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :type: str
        """

        self._raid_read_mode = raid_read_mode

    @property
    def allocation_zone_name(self):
        """Gets the allocation_zone_name of this InlineResponse20017ResponseVcontrollers.  # noqa: E501


        :return: The allocation_zone_name of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :rtype: str
        """
        return self._allocation_zone_name

    @allocation_zone_name.setter
    def allocation_zone_name(self, allocation_zone_name):
        """Sets the allocation_zone_name of this InlineResponse20017ResponseVcontrollers.


        :param allocation_zone_name: The allocation_zone_name of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :type: str
        """

        self._allocation_zone_name = allocation_zone_name

    @property
    def allocation_zone_display_name(self):
        """Gets the allocation_zone_display_name of this InlineResponse20017ResponseVcontrollers.  # noqa: E501


        :return: The allocation_zone_display_name of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :rtype: str
        """
        return self._allocation_zone_display_name

    @allocation_zone_display_name.setter
    def allocation_zone_display_name(self, allocation_zone_display_name):
        """Sets the allocation_zone_display_name of this InlineResponse20017ResponseVcontrollers.


        :param allocation_zone_display_name: The allocation_zone_display_name of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :type: str
        """

        self._allocation_zone_display_name = allocation_zone_display_name

    @property
    def smb_unix_charset(self):
        """Gets the smb_unix_charset of this InlineResponse20017ResponseVcontrollers.  # noqa: E501


        :return: The smb_unix_charset of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :rtype: str
        """
        return self._smb_unix_charset

    @smb_unix_charset.setter
    def smb_unix_charset(self, smb_unix_charset):
        """Sets the smb_unix_charset of this InlineResponse20017ResponseVcontrollers.


        :param smb_unix_charset: The smb_unix_charset of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :type: str
        """

        self._smb_unix_charset = smb_unix_charset

    @property
    def smb_dos_charset(self):
        """Gets the smb_dos_charset of this InlineResponse20017ResponseVcontrollers.  # noqa: E501


        :return: The smb_dos_charset of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :rtype: str
        """
        return self._smb_dos_charset

    @smb_dos_charset.setter
    def smb_dos_charset(self, smb_dos_charset):
        """Sets the smb_dos_charset of this InlineResponse20017ResponseVcontrollers.


        :param smb_dos_charset: The smb_dos_charset of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :type: str
        """

        self._smb_dos_charset = smb_dos_charset

    @property
    def vpsa_uuid(self):
        """Gets the vpsa_uuid of this InlineResponse20017ResponseVcontrollers.  # noqa: E501


        :return: The vpsa_uuid of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :rtype: str
        """
        return self._vpsa_uuid

    @vpsa_uuid.setter
    def vpsa_uuid(self, vpsa_uuid):
        """Sets the vpsa_uuid of this InlineResponse20017ResponseVcontrollers.


        :param vpsa_uuid: The vpsa_uuid of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :type: str
        """

        self._vpsa_uuid = vpsa_uuid

    @property
    def sod_end_time(self):
        """Gets the sod_end_time of this InlineResponse20017ResponseVcontrollers.  # noqa: E501


        :return: The sod_end_time of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :rtype: str
        """
        return self._sod_end_time

    @sod_end_time.setter
    def sod_end_time(self, sod_end_time):
        """Sets the sod_end_time of this InlineResponse20017ResponseVcontrollers.


        :param sod_end_time: The sod_end_time of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :type: str
        """

        self._sod_end_time = sod_end_time

    @property
    def wwpn_count(self):
        """Gets the wwpn_count of this InlineResponse20017ResponseVcontrollers.  # noqa: E501


        :return: The wwpn_count of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :rtype: int
        """
        return self._wwpn_count

    @wwpn_count.setter
    def wwpn_count(self, wwpn_count):
        """Sets the wwpn_count of this InlineResponse20017ResponseVcontrollers.


        :param wwpn_count: The wwpn_count of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :type: int
        """

        self._wwpn_count = wwpn_count

    @property
    def integrity_status(self):
        """Gets the integrity_status of this InlineResponse20017ResponseVcontrollers.  # noqa: E501


        :return: The integrity_status of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :rtype: str
        """
        return self._integrity_status

    @integrity_status.setter
    def integrity_status(self, integrity_status):
        """Sets the integrity_status of this InlineResponse20017ResponseVcontrollers.


        :param integrity_status: The integrity_status of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :type: str
        """

        self._integrity_status = integrity_status

    @property
    def iser_support(self):
        """Gets the iser_support of this InlineResponse20017ResponseVcontrollers.  # noqa: E501


        :return: The iser_support of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :rtype: str
        """
        return self._iser_support

    @iser_support.setter
    def iser_support(self, iser_support):
        """Sets the iser_support of this InlineResponse20017ResponseVcontrollers.


        :param iser_support: The iser_support of this InlineResponse20017ResponseVcontrollers.  # noqa: E501
        :type: str
        """

        self._iser_support = iser_support

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20017ResponseVcontrollers, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20017ResponseVcontrollers):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20017ResponseVcontrollers):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from CommandCenter.api_client import ApiClient


class LogsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_address_to_remote_rsyslog_server_list(self, cloud_name, add_address_to_remote_rsyslog_server_list, **kwargs):  # noqa: E501
        """add_address_to_remote_rsyslog_server_list  # noqa: E501

        Adds an address to the list of remote RSYSLOG server.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_address_to_remote_rsyslog_server_list(cloud_name, add_address_to_remote_rsyslog_server_list, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param AddAddressToRemoteRsyslogServerList add_address_to_remote_rsyslog_server_list: (required)
        :return: InlineResponse20036
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_address_to_remote_rsyslog_server_list_with_http_info(cloud_name, add_address_to_remote_rsyslog_server_list, **kwargs)  # noqa: E501
        else:
            (data) = self.add_address_to_remote_rsyslog_server_list_with_http_info(cloud_name, add_address_to_remote_rsyslog_server_list, **kwargs)  # noqa: E501
            return data

    def add_address_to_remote_rsyslog_server_list_with_http_info(self, cloud_name, add_address_to_remote_rsyslog_server_list, **kwargs):  # noqa: E501
        """add_address_to_remote_rsyslog_server_list  # noqa: E501

        Adds an address to the list of remote RSYSLOG server.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_address_to_remote_rsyslog_server_list_with_http_info(cloud_name, add_address_to_remote_rsyslog_server_list, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param AddAddressToRemoteRsyslogServerList add_address_to_remote_rsyslog_server_list: (required)
        :return: InlineResponse20036
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'add_address_to_remote_rsyslog_server_list']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_address_to_remote_rsyslog_server_list" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `add_address_to_remote_rsyslog_server_list`")  # noqa: E501
        # verify the required parameter 'add_address_to_remote_rsyslog_server_list' is set
        if self.api_client.client_side_validation and ('add_address_to_remote_rsyslog_server_list' not in params or
                                                       params['add_address_to_remote_rsyslog_server_list'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `add_address_to_remote_rsyslog_server_list` when calling `add_address_to_remote_rsyslog_server_list`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_address_to_remote_rsyslog_server_list' in params:
            body_params = params['add_address_to_remote_rsyslog_server_list']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/logs/add_remote_address.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20036',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_address_from_remote_rsyslog_server_list(self, cloud_name, delete_address_from_remote_rsyslog_server_list, **kwargs):  # noqa: E501
        """delete_address_from_remote_rsyslog_server_list  # noqa: E501

        Deletes the supplied address from the list of remote RSYSLOG servers.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_address_from_remote_rsyslog_server_list(cloud_name, delete_address_from_remote_rsyslog_server_list, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param DeleteAddressFromRemoteRsyslogServerList delete_address_from_remote_rsyslog_server_list: (required)
        :return: InlineResponse20036
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_address_from_remote_rsyslog_server_list_with_http_info(cloud_name, delete_address_from_remote_rsyslog_server_list, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_address_from_remote_rsyslog_server_list_with_http_info(cloud_name, delete_address_from_remote_rsyslog_server_list, **kwargs)  # noqa: E501
            return data

    def delete_address_from_remote_rsyslog_server_list_with_http_info(self, cloud_name, delete_address_from_remote_rsyslog_server_list, **kwargs):  # noqa: E501
        """delete_address_from_remote_rsyslog_server_list  # noqa: E501

        Deletes the supplied address from the list of remote RSYSLOG servers.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_address_from_remote_rsyslog_server_list_with_http_info(cloud_name, delete_address_from_remote_rsyslog_server_list, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param DeleteAddressFromRemoteRsyslogServerList delete_address_from_remote_rsyslog_server_list: (required)
        :return: InlineResponse20036
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'delete_address_from_remote_rsyslog_server_list']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_address_from_remote_rsyslog_server_list" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `delete_address_from_remote_rsyslog_server_list`")  # noqa: E501
        # verify the required parameter 'delete_address_from_remote_rsyslog_server_list' is set
        if self.api_client.client_side_validation and ('delete_address_from_remote_rsyslog_server_list' not in params or
                                                       params['delete_address_from_remote_rsyslog_server_list'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `delete_address_from_remote_rsyslog_server_list` when calling `delete_address_from_remote_rsyslog_server_list`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'delete_address_from_remote_rsyslog_server_list' in params:
            body_params = params['delete_address_from_remote_rsyslog_server_list']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/logs/delete_remote_addresses.json', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20036',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_recent_event(self, cloud_name, **kwargs):  # noqa: E501
        """list_recent_event  # noqa: E501

        Gets a list of recent events.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_recent_event(cloud_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param int min_severity:
        :param str template:
        :param str min_time:
        :param str max_time:
        :param int min_id:
        :param int max_id:
        :param str orderby:
        :param bool desc:
        :param int page: The page number to start from.
        :param int per_page: The total number of records to return.
        :param str attributes: e.g attributes[source_type]=sn&attributes[source_name]=s1
        :return: InlineResponse20035
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_recent_event_with_http_info(cloud_name, **kwargs)  # noqa: E501
        else:
            (data) = self.list_recent_event_with_http_info(cloud_name, **kwargs)  # noqa: E501
            return data

    def list_recent_event_with_http_info(self, cloud_name, **kwargs):  # noqa: E501
        """list_recent_event  # noqa: E501

        Gets a list of recent events.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_recent_event_with_http_info(cloud_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param int min_severity:
        :param str template:
        :param str min_time:
        :param str max_time:
        :param int min_id:
        :param int max_id:
        :param str orderby:
        :param bool desc:
        :param int page: The page number to start from.
        :param int per_page: The total number of records to return.
        :param str attributes: e.g attributes[source_type]=sn&attributes[source_name]=s1
        :return: InlineResponse20035
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'min_severity', 'template', 'min_time', 'max_time', 'min_id', 'max_id', 'orderby', 'desc', 'page', 'per_page', 'attributes']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_recent_event" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `list_recent_event`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501

        query_params = []
        if 'min_severity' in params:
            query_params.append(('min_severity', params['min_severity']))  # noqa: E501
        if 'template' in params:
            query_params.append(('template', params['template']))  # noqa: E501
        if 'min_time' in params:
            query_params.append(('min_time', params['min_time']))  # noqa: E501
        if 'max_time' in params:
            query_params.append(('max_time', params['max_time']))  # noqa: E501
        if 'min_id' in params:
            query_params.append(('min_id', params['min_id']))  # noqa: E501
        if 'max_id' in params:
            query_params.append(('max_id', params['max_id']))  # noqa: E501
        if 'orderby' in params:
            query_params.append(('orderby', params['orderby']))  # noqa: E501
        if 'desc' in params:
            query_params.append(('desc', params['desc']))  # noqa: E501
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'per_page' in params:
            query_params.append(('per_page', params['per_page']))  # noqa: E501
        if 'attributes' in params:
            query_params.append(('attributes', params['attributes']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/logs.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20035',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def retrieve_address_of_remote_rsyslog_server_list(self, cloud_name, **kwargs):  # noqa: E501
        """retrieve_address_of_remote_rsyslog_server_list  # noqa: E501

        Retrieve the the address list of a remote RSYSLOG servers.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_address_of_remote_rsyslog_server_list(cloud_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :return: InlineResponse20037
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.retrieve_address_of_remote_rsyslog_server_list_with_http_info(cloud_name, **kwargs)  # noqa: E501
        else:
            (data) = self.retrieve_address_of_remote_rsyslog_server_list_with_http_info(cloud_name, **kwargs)  # noqa: E501
            return data

    def retrieve_address_of_remote_rsyslog_server_list_with_http_info(self, cloud_name, **kwargs):  # noqa: E501
        """retrieve_address_of_remote_rsyslog_server_list  # noqa: E501

        Retrieve the the address list of a remote RSYSLOG servers.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_address_of_remote_rsyslog_server_list_with_http_info(cloud_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :return: InlineResponse20037
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retrieve_address_of_remote_rsyslog_server_list" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `retrieve_address_of_remote_rsyslog_server_list`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/logs/remote_addresses.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20037',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)
